"""
docker镜像配置文件
"""
from typing import List

DOCKER_MIRRORS: List[str] = [
    "docker.ama.moe", # leaflow 镜像
    "docker.xuanyuan.me", # 轩辕镜像
    "docker.1ms.run", # 1毫秒
    "smwyfknvowek.ap-northeast-1.clawcloudrun.com", # 自建镜像
]